===============================
lcubo_helpers
===============================


.. image:: https://img.shields.io/pypi/v/lcubo_helpers.svg
        :target: https://pypi.python.org/pypi/lcubo_helpers

.. image:: https://img.shields.io/travis/llazzaro/lcubo_helpers.svg
        :target: https://travis-ci.org/llazzaro/lcubo_helpers

.. image:: https://readthedocs.org/projects/lcubo-helpers/badge/?version=latest
        :target: https://lcubo-helpers.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://requires.io/github/llazzaro/lcubo_helpers/requirements.svg?branch=master
        :target: https://requires.io/github/llazzaro/lcubo_helpers/requirements?branch=master
        :alt: Dependencies


some functions and classes I copy paste in several projects. this is a kitten saver


* Free software: MIT license
* Documentation: https://lcubo-helpers.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
